@@ -12,6 +12,6 @@ pub enum RossConvertPacketError {
 }
 
 pub trait RossConvertPacket<T> {
-    fn try_from_packet(packet: RossPacket) -> Result<T, RossConvertPacketError>;
+    fn try_from_packet(packet: &RossPacket) -> Result<T, RossConvertPacketError>;
     fn to_packet(&self) -> RossPacket;
 }
